==> audiowiki_1.0.2-23.tar.gz: audiowiki-1.0.2/datahandler.cpp <==
#include "datahandler.h"
#include <QDesktopServices>
#define SEARCH 1
#define ARTICLE 2
#define PARSE 3

DataHandler::DataHandler(QObject *parent) :
    QObject(parent)
{
    parser = new XMLParser();
    articleParser = new ArticleParser();
    savedFiles = new QList<QString>();
    allLoadedFiles = new QList<QString>();
}

DataHandler::~DataHandler()
{

}

void DataHandler::dataReceived(QNetworkReply *reply, int mode)
{
    if (mode == SEARCH)
        searchTitles = parser->parseSearchTitles(reply);
    else if (mode == ARTICLE)
    {
        articleContent = parser->parseArticleContent(reply);
        this->saveArticleToFile(articleContent);
    }
}

QList<QString> DataHandler::getSearchTitles()
{
    return this->searchTitles;
}

QMap<QString, QStringList> DataHandler::getArticleContent()
{
    return this->articleContent;
}

void DataHandler::setCurrentArticle(QString articleName)
{
    this->currentArticleTitle = articleName;
}

void DataHandler::saveArticleToFile(QMap<QString, QStringList> content)
{
    article = new QFile("/home/user/MyDocs/.audiowiki/" +  currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".txt");
    articleLinks = new QFile("/home/user/MyDocs/.audiowiki/" +  currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".dat");
    if (!article->open(QIODevice::WriteOnly))
        qDebug()<<"file error";
    else
    {
        QString articleText = articleParser->parseArticleContent(content.keys().at(0));
        QTextStream articleContent(article);
        articleContent << articleText;
        article->close();
    }
    if (articleLinks->open(QIODevice::WriteOnly))
    {
        QDataStream out(articleLinks);   // we will serialize the data into the file
        out << content.value(content.keys().at(0));
        articleLinks->close();
    }
    articleLinkList = content.value(content.keys().at(0));
    allLoadedFiles->append(currentArticleTitle);
    qDebug()<<"articleSaved";
}

QString DataHandler::getArticleFromFile()
{

    QString line;
    QFile file("/home/user/MyDocs/.audiowiki/" +  currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".txt");
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
        return "";

    QTextStream in(&file);
    while (!in.atEnd())
    {
        line.append(in.readLine());
    }

    //line = articleParser->parseArticleContent(line);



    return line;
}

QString DataHandler::getCurrentArticleTitle()
{
    return this->currentArticleTitle;
}

void DataHandler::addFileToSaved(QString title)
{
    this->savedFiles->append(title);
}

void DataHandler::removeFiles()
{
    for(int i = 0; i<allLoadedFiles->count(); i++)
    {
        if (!savedFiles->contains(allLoadedFiles->at(i)))
        {
            QFile textFile("/home/user/MyDocs/.audiowiki/" +  allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".txt");
            textFile.remove();
            QFile datFile("/home/user/MyDocs/.audiowiki/" +  allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".dat");
            datFile.remove();
            QFile soundFile("/home/user/MyDocs/.audiowiki/" +  allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".wav");
            soundFile.remove();
        }
    }
}

==> audiowiki_1.0.3-6.tar.gz: audiowiki-1.0.3/datahandler.cpp <==
#include "datahandler.h"
#include <QDesktopServices>
#define SEARCH 1
#define ARTICLE 2
#define PARSE 3

DataHandler::DataHandler(QObject *parent) :
    QObject(parent)
{
    parser = new XMLParser();
    articleParser = new ArticleParser();
    savedFiles = new QList<QString>();
    allLoadedFiles = new QList<QString>();
}

DataHandler::~DataHandler()
{

}

void DataHandler::dataReceived(QNetworkReply *reply, int mode)
{
    if (mode == SEARCH)
        searchTitles = parser->parseSearchTitles(reply);
    else if (mode == ARTICLE)
    {
        articleContent = parser->parseArticleContent(reply);
        this->saveArticleToFile(articleContent);
    }
}

QList<QString> DataHandler::getSearchTitles()
{
    return this->searchTitles;
}

QMap<QString, QStringList> DataHandler::getArticleContent()
{
    return this->articleContent;
}

void DataHandler::setCurrentArticle(QString articleName)
{
    this->currentArticleTitle = articleName;
    this->strippedtitle = currentArticleTitle.toLower().remove(QRegExp("[^A-Za-z0-9]"));
}

void DataHandler::saveArticleToFile(QMap<QString, QStringList> content)
{
  //  this->currentArticleTitle =
    this->strippedtitle = currentArticleTitle.toLower().remove(QRegExp("[^A-Za-z0-9]"));
    article = new QFile("/home/user/MyDocs/.audiowiki/" +  strippedtitle+".txt");
    articleLinks = new QFile("/home/user/MyDocs/.audiowiki/" +  strippedtitle+".dat");
    if (!article->open(QIODevice::WriteOnly))
        qDebug()<<"file error";
    else
    {
        QString articleText = articleParser->parseArticleContent(content.keys().at(0));
        QTextStream articleContent(article);
        articleContent << articleText;
        article->close();
    }
    if (articleLinks->open(QIODevice::WriteOnly))
    {
        QDataStream out(articleLinks);   // we will serialize the data into the file
        out << content.value(content.keys().at(0));
        articleLinks->close();
    }
    articleLinkList = content.value(content.keys().at(0));
    allLoadedFiles->append(strippedtitle);
    qDebug()<<"articleSaved";
}

QString DataHandler::getArticleFromFile()
{

    QString line;
    QFile file("/home/user/MyDocs/.audiowiki/" +  strippedtitle+".txt");
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
        return "";

    QTextStream in(&file);
    while (!in.atEnd())
    {
        line.append(in.readLine());
    }

    //line = articleParser->parseArticleContent(line);



    return line;
}

QString DataHandler::getCurrentArticleTitle()
{
    return this->currentArticleTitle;
}

void DataHandler::addFileToSaved(QString title)
{
    this->savedFiles->append(title);
}

void DataHandler::removeFiles()
{
    parsed = new QList<QString>();
    for(int i = 0; i < savedFiles->count(); i ++)
    {
        parsed->append(savedFiles->at(i).toLower().remove(QRegExp("[^A-Za-z0-9]")));
    }
    for(int i = 0; i<allLoadedFiles->count(); i++)
    {

        if (!parsed->contains(allLoadedFiles->at(i)))
        {
            QFile textFile("/home/user/MyDocs/.audiowiki/" +  allLoadedFiles->at(i).toLower()+".txt");
            textFile.remove();
            QFile datFile("/home/user/MyDocs/.audiowiki/" +  allLoadedFiles->at(i).toLower()+".dat");
            datFile.remove();
            QFile soundFile("/home/user/MyDocs/.audiowiki/" +  allLoadedFiles->at(i).toLower()+".wav");
            soundFile.remove();
        }

    }
}
